@@ -1,9 +1,9 @@
 # as.char.R: brief description of an object as a string e.g. "c(1,2)"
-#            also includes print_summary for summarizing matrices and data.frames
+#            this file also includes print_summary for matrices and data.frames
 
 as.char <- function(object, maxlen=20)
 {
-    stopifnot(is.numeric(maxlen), length(maxlen) == 1, maxlen > 0)
+    check.integer.scalar(maxlen, min=1)
 
     if(is.null(object))
         "NULL"
@@ -32,11 +32,14 @@ as.char <- function(object, maxlen=20)
         paste.c(signif(zapsmall(object, digits=4), digits=4))
     }
     else if(length(dim(object)) == 2)
-        sprintf("%s[%g,%g]", class(object)[1], NROW(object), NCOL(object))
+        sprint("%s[%g,%g]", class(object)[1], NROW(object), NCOL(object))
 
     else if(class(object)[1] == "list") # not is.list() because e.g. lm objects are lists
         paste0("list(", paste.trunc(list.as.char(object), maxlen=maxlen+12), ")")
 
+    else if(class(object)[1] == "Date")
+        paste0("Date:", paste.trunc(object, maxlen=maxlen+12))
+
     else
         paste0(class(object)[1], ".object")
 }
@@ -50,14 +53,14 @@ list.as.char <- function(object, maxlen=20)
     names <- names(object)
     for(i in seq_along(object)) {
         if(i != 1)
-            s <- sprintf("%s, ", s)
+            s <- sprint("%s, ", s)
         name.ok <- length(names) >= i && !is.na(names[i]) && nzchar(names[i])
         if(name.ok && names[i] == "...")
-            s <- sprintf("%s...", s) # print dots as ... not as ...=pairlist.object
+            s <- sprint("%s...", s) # print dots as ... not as ...=pairlist.object
         else {
             if(name.ok)
-                s <- sprintf("%s%s=", s, names(object)[i])
-            s <- sprintf("%s%s", s, as.char(object[[i]], maxlen=maxlen))
+                s <- sprint("%s%s=", s, names(object)[i])
+            s <- sprint("%s%s", s, as.char(object[[i]], maxlen=maxlen))
         }
     }
     s    # one element character vector e.g "x=1, 2"
@@ -77,9 +80,9 @@ environment.as.char <- function(env, maxlen=60) # compact description
         stripped.env # something like "namespace:stats" or "R_GlobalEnv"
 
     else # return the names of the objects in the environment
-        sprintf("env(%s)",
-                paste.trunc(paste0(ls(env, all.names=TRUE), collapse=", "),
-                            maxlen=maxlen))
+        sprint("env(%s)",
+               paste.trunc(paste0(ls(env, all.names=TRUE), collapse=", "),
+                           maxlen=maxlen))
 }
 # The main purpose of this routine is to summarize matrices and data.frames,
 # but it will also (semi)gracefully handle any object that is passed to it.
@@ -98,7 +101,7 @@ environment.as.char <- function(env, maxlen=60) # compact description
 print_summary <- function(x, xname=trunc.deparse(substitute(x)),
                           trace=2, msg="", prefix="", details=2)
 {
-    stopifnot(is.numeric(trace))
+    check.numeric.scalar(trace)
     if(trace < 2)
         return()
     if(is.null(x)) {
@@ -136,19 +139,19 @@ print_summary <- function(x, xname=trunc.deparse(substitute(x)),
     }
     df <- try(my.data.frame(x, trace, stringsAsFactors=FALSE), silent=TRUE)
     if(is.try.err(df)) { # be robust for whatever gets passed to this function
-        printf("print_summary: cannot convert class \"%s\" to a data.frame\n",
-               class(x)[1])
+        printf("print_summary: cannot convert class \"%s\" to a data.frame (%s)\n",
+               class(x)[1], cleantry(df))
         printf("%s%s%s:\n", prefix, xname, msg)
         if(length(dim(x)) == 2) { # it's a matrix or other 2D object?
             if(trace >= 4) {
-                try(print.with.strings.quoted(x))
+                try(print_with_strings_quoted(x))
                 try(print(summary(x)))
             } else {
-                try(print.with.strings.quoted(head(x)))
+                try(print_with_strings_quoted(head(x)))
                 printf("...\n")
             }
         } else
-            try(print.with.strings.quoted(x))
+            try(print_with_strings_quoted(x))
         return()
     }
     if(details < 2 && trace < 4) {
@@ -157,7 +160,12 @@ print_summary <- function(x, xname=trunc.deparse(substitute(x)),
             printf("        ")
         printf("%s%s[%d,%d]%s ",
                 prefix, xname, nrow(df), ncol(df), msg)
-        print.colnames(x, full=details == 2)
+        print_colnames(x, full=details == 2, newline="")
+        if(NCOL(x) == 1 || NROW(x) == 1) # if a vector, print first few values
+            cat0(", and values ", # if double, print 4 significant digits
+                 paste.trunc(if(is.double(x)) sprint("%.4g", x) else x,
+                             collapse=", ", maxlen=32))
+        cat0("\n")
         return()
     }
     colnames <- safe.colnames(x)
@@ -179,10 +187,10 @@ print_summary <- function(x, xname=trunc.deparse(substitute(x)),
         if(!is.null(colnames))
             colnames(df.short)[maxcols] <- "..."
     }
-    try(print.with.strings.quoted(df.short))
+    try(print_with_strings_quoted(df.short))
     is.fac <- sapply(df, is.factor)
     if(is.null(colnames))
-        colnames(df) <- sprintf("[,%d]", seq_len(NCOL(x)))
+        colnames(df) <- sprint("[,%d]", seq_len(NCOL(x)))
     if(any(is.fac)) {
         names <- paste0(colnames(df),
                         ifelse(sapply(df, is.ordered), "(ordered)", ""))
@@ -196,21 +204,23 @@ print_summary <- function(x, xname=trunc.deparse(substitute(x)),
     if(trace >= 4)
         try(print(summary(df)))
 }
-print.colnames <- function(x, full=FALSE)
+print_colnames <- function(x, full=FALSE, newline="\n")
 {
     colnames <- safe.colnames(x)
     if(is.null(colnames))
-        printf("with no column names\n")
+        printf("with no column names%s", newline)
     else {
         colnames[which(colnames == "")] <- "\"\""
         if(full) # full colnames (up to 1000 characters)
-            printf("with colname%s %s\n",
+            printf("with colname%s %s%s",
                 if(length(colnames(x)) > 1) "s" else "",
-                paste.trunc(colnames, maxlen=getOption("width")-20))
+                paste.trunc(colnames, maxlen=max(25, getOption("width")-20)),
+                newline)
         else # short version of colnames
-            printf.wrap("with colname%s %s\n",
+            printf.wrap("with colname%s %s%s",
                 if(length(colnames(x)) > 1) "s" else "",
-                paste.trunc(colnames))
+                paste.trunc(colnames),
+                newline)
     }
 }
 # Like print but puts quotes around strings.
@@ -219,7 +229,7 @@ print.colnames <- function(x, full=FALSE)
 # "..." is not quoted because it is used as a
 # "something was deleted" indicator in print_summary
 
-print.with.strings.quoted <- function(x)
+print_with_strings_quoted <- function(x)
 {
     if(length(dim(x)) == 2)
         for(i in seq_len(NCOL(x)))
